# ⚡️superbus
Redis-based bus to create multi-stage pipelines for long-running tasks

In development </br>
Docs coming soon </br>

You can check `examples` for now


### Installation
```
pip install superbus
```